@@ -1,15 +1,16 @@
+from django.contrib.sites.shortcuts import get_current_site
 from django.contrib.syndication.views import Feed
-from django.contrib.sites.models import get_current_site
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 import django_comments
 
+
 class LatestCommentFeed(Feed):
     """Feed of latest comments on the current site."""
 
     def __call__(self, request, *args, **kwargs):
         self.site = get_current_site(request)
-        return super(LatestCommentFeed, self).__call__(request, *args, **kwargs)
+        return super().__call__(request, *args, **kwargs)
 
     def title(self):
         return _("%(site_name)s comments") % dict(site_name=self.site.name)
@@ -22,9 +23,9 @@ class LatestCommentFeed(Feed):
 
     def items(self):
         qs = django_comments.get_model().objects.filter(
-            site__pk = self.site.pk,
-            is_public = True,
-            is_removed = False,
+            site__pk=self.site.pk,
+            is_public=True,
+            is_removed=False,
         )
         return qs.order_by('-submit_date')[:40]
 
